#
# spec file for package python-zope.schema
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-zope.schema%{psuffix}
Version:        5.0.1
Release:        bp155.3.3.1
Summary:        Zope interface extension for defining data schemas
License:        ZPL-2.1
URL:            https://pypi.python.org/pypi/zope.schema
Source:         https://files.pythonhosted.org/packages/source/z/zope.schema/zope.schema-%{version}.tar.gz
# PATCH-FIX-UPSTREAM: fix-outsized-integer-test.patch -- gh#zopefoundation/zope.schema@d7126a481e5c, bsc#1210186
Patch0:         fix-outsized-integer-test.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-zope.event
Requires:       python-zope.interface >= 3.6.0
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module zope.event}
BuildRequires:  %{python_module zope.i18nmessageid}
BuildRequires:  %{python_module zope.interface >= 3.6.0}
BuildRequires:  %{python_module zope.testing}
BuildRequires:  %{python_module zope.testrunner}
%endif
%python_subpackages

%description
Schemas extend the notion of interfaces to detailed descriptions of
Attributes (but not methods).  Every schema is an interface and
specifies the public fields of an object.  A *field* roughly
corresponds to an attribute of a Python object.  But a Field provides
space for at least a title and a description.  It can also constrain
its value and provide a validation method.  Besides you can optionally
specify characteristics such as its value being read-only or not
required.

%prep
%autosetup -p1 -n zope.schema-%{version}
rm -rf zope.schema.egg-info

%build
%python_build

%install
%if !%{with test}
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%python_expand PYTHONPATH=src %{_bindir}/zope-testrunner-%{$python_bin_suffix} -vvv --test-path src
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc COPYRIGHT.txt CHANGES.rst README.rst
%{python_sitelib}/*
%endif

%changelog
* Mon Jul  3 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add fix-outsized-integer-test.patch, to fix outsized integer test
  values that break tests on newer Python versions (bsc#1210186,
  gh#zopefoundation/zope.schema@d7126a481e5c)
* Mon Mar  9 2020 pgajdos@suse.com
- update to version 5.0.1
  - Fix: add ``Text.unicode_normalization = 'NFC'`` as default, because some are
    persisting schema fields. Setting that attribute only in ``__init__``
    breaks loading old objects.
  - Set ``IDecimal`` attributes ``min``, ``max`` and ``default`` as ``Decimal``
    type instead of ``Number``.
    See `issue 88 <https://github.com/zopefoundation/zope.schema/issues/88>`_.
  - Enable unicode normalization for ``Text`` fields.
    The default is NFC normalization. Valid forms are 'NFC', 'NFKC', 'NFD', and
    'NFKD'. To disable normalization, set ``unicode_normalization`` to ``False``
    or ``None`` when calling ``__init__`` of the ``Text`` field.
    See `issue 86 <https://github.com/zopefoundation/zope.schema/issues/86>`_.
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Tue Apr  2 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 4.9.3
  4.5.0:
  * Add support for Python 3.5 and 3.6.
  * Drop support for Python 2.6, 3.2, and 3.3.
  * Drop support for ‘setup.py test’. Use zope.testrunner instead.
  4.6.0
  * Add support for Python 3.7.
  * Choice, SimpleVocabulary and SimpleTerm all gracefully handle
    using Unicode token values with non-ASCII characters by encoding
    them with the backslashreplace error handler.
  * Add fields and interfaces representing Python’s numeric tower.
  * More various enhancements.
  4.6.1
  * Fix the Field constructor to again allow MessageID values for
    the description.
  4.6.2
  * Fix checking a field’s constraint to set the field and value
    properties if the constraint raises a ValidationError.
  4.7.0
  * Give various classes some fields.
  4.8.0
  * Fix passing None as the description to a field constructor.
  4.9.0
  * Make NativeString and NativeStringLine distinct types.
  * Fix Field.getDoc() when value_type or key_type is present.
  * Make DottedName accept leading underscores for each segment.
  4.9.1
  * Fix SimpleTerm token for non-ASCII bytes values.
  4.9.2
  * Make sure that the title for IObject.validate_invariants is a
    unicode string.
  4.9.3
  * Fixed a ReST error in getDoc() results when having “subfields”
    with titles.
- drop *-doc subpackage, use multibuild instead
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jul 13 2017 aloisio@gmx.com
- Converted to single-spec
- Split docs and tests into separate -doc package since running
  tests and sometimes building docs had become very messy.
  Also see (gh#/zopefoundation/zope.proxy#18)
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.4.2:
  * Fix description of min max field: max value is included,
    not excluded.
- additional changes from version 4.4.1:
  * Added support for Python 3.4.
- switch the source archive to tar.gz (zip not available)
- remove unzip from BuildRequires
- pass -q to test to avoid spamming the build log
* Fri Feb 28 2014 os-dev@jacraig.com
- Update to 4.4.0:
  * Add an event on field properties to notify that a field has been updated.
    This event enables definition of subscribers based on an event, a context
    and a field. The event contains also the old value and the new value.
    (also see package ``zope.schemaevent`` that define a field event handler)
- Changes from 4.3.3:
  * PEP 8 cleanup.
  * Don't raise RequiredMissing if a field's defaultFactory returns the field's
    missing_value.
  * Updated ``boostrap.py`` to version 2.2.
  * Add the ability to swallow ValueErrors when rendering a SimpleVocabulary,
    allowing for cases where vocabulary items may be duplicated (e.g., due to
    user input).
  * It was a pain that ``ConstraintNotSatisfied`` did not tell the field name.
* Mon Jul 29 2013 hpj@urpla.net
- generate separate -doc package
* Wed Mar 20 2013 speilicke@suse.com
- Add (Build)Requires python-ordereddict for SLE_11 only
* Fri Mar 15 2013 speilicke@suse.com
- Initial version
